@@ -1,6 +1,6 @@
 # Distributions menu dialogs
 
-# last modified 20 May 03 by J. Fox
+# last modified 11 June 03 by J. Fox
 
 normalQuantiles <- function(){
     top <- tktoplevel()
@@ -51,17 +51,23 @@ normalQuantiles <- function(){
     tkgrid(tklabel(top, text="sigma (standard deviation)"), sigmaEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(quantilesEntry, sticky="w")
     tkgrid.configure(muEntry, sticky="w")
     tkgrid.configure(sigmaEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(quantilesEntry)
+    tkwait.window(top)
     }
 
 normalProbabilities <- function(){
@@ -113,17 +119,23 @@ normalProbabilities <- function(){
     tkgrid(tklabel(top, text="sigma (standard deviation)"), sigmaEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(probabilitiesEntry, sticky="w")
     tkgrid.configure(muEntry, sticky="w")
     tkgrid.configure(sigmaEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(probabilitiesEntry)
+    tkwait.window(top)
     }
 
 tQuantiles <- function(){
@@ -179,16 +191,22 @@ tQuantiles <- function(){
     tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(quantilesEntry, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:4) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(quantilesEntry)
+    tkwait.window(top)
     }
     
 tProbabilities <- function(){
@@ -245,16 +263,22 @@ tProbabilities <- function(){
     tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(probabilitiesEntry, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:4) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(probabilitiesEntry)
+    tkwait.window(top)
     }
 
 chisqQuantiles <- function(){
@@ -310,16 +334,22 @@ chisqQuantiles <- function(){
     tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(quantilesEntry, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:4) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(quantilesEntry)
+    tkwait.window(top)
     }
     
 chisqProbabilities <- function(){
@@ -375,16 +405,22 @@ chisqProbabilities <- function(){
     tkgrid(tklabel(top, text="Degrees of freedom"), dfEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(probabilitiesEntry, sticky="w")
     tkgrid.configure(dfEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:4) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(probabilitiesEntry)
+    tkwait.window(top)
     }
 
 FQuantiles <- function(){
@@ -444,17 +480,23 @@ FQuantiles <- function(){
     tkgrid(tklabel(top, text="Denominator degrees of freedom"), df2Entry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(quantilesEntry, sticky="w")
     tkgrid.configure(df1Entry, sticky="w")
     tkgrid.configure(df2Entry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(quantilesEntry)
+    tkwait.window(top)
     }
     
 FProbabilities <- function(){
@@ -514,17 +556,23 @@ FProbabilities <- function(){
     tkgrid(tklabel(top, text="Denominator degrees of freedom"), df2Entry, sticky="e")    
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(probabilitiesEntry, sticky="w")
     tkgrid.configure(df1Entry, sticky="w")
     tkgrid.configure(df2Entry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(probabilitiesEntry)
+    tkwait.window(top)
     }
 
 binomialQuantiles <- function(){
@@ -592,17 +640,23 @@ binomialQuantiles <- function(){
     tkgrid(tklabel(top, text="Probability of success"), probEntry, sticky="e")
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(quantilesEntry, sticky="w")
     tkgrid.configure(trialsEntry, sticky="w")
     tkgrid.configure(probEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(quantilesEntry)
+    tkwait.window(top)
     }
     
 binomialProbabilities <- function(){
@@ -670,17 +724,23 @@ binomialProbabilities <- function(){
     tkgrid(tklabel(top, text="Probability of success"), probEntry, sticky="e")    
     tkgrid(tklabel(top, text="Lower tail"), lowerTailButton, sticky="e")
     tkgrid(tklabel(top, text="Upper tail"), upperTailButton, sticky="e")
+    tkgrid(OKbutton, cancelButton, sticky="w")
+    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(probabilitiesEntry, sticky="w")
     tkgrid.configure(trialsEntry, sticky="w")
     tkgrid.configure(probEntry, sticky="w")
     tkgrid.configure(lowerTailButton, sticky="w")
     tkgrid.configure(upperTailButton, sticky="w")
-    tkgrid(OKbutton, cancelButton, sticky="w")
-    tkgrid(buttonsFrame, helpButton, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:5) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(probabilitiesEntry)
+    tkwait.window(top)
     }
 
 binomialMass <- function(){
@@ -749,12 +809,18 @@ binomialMass <- function(){
     helpButton <- tkbutton(top, text="Help", width="12", command=onHelp)
     tkgrid(tklabel(top, text="Binomial trials"), trialsEntry, sticky="e")
     tkgrid(tklabel(top, text="Probability of success"), probEntry, sticky="e")
-    tkgrid.configure(trialsEntry, sticky="w")
-    tkgrid.configure(probEntry, sticky="w")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, tklabel(top, text="    "), helpButton, sticky="w")
+    tkgrid.configure(trialsEntry, sticky="w")
+    tkgrid.configure(probEntry, sticky="w")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:2) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkbind(top, "<Return>", onOK)
-    tkfocus(top)
-    tkgrab(top)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
+    tkfocus(trialsEntry)
+    tkwait.window(top)
     }
