@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 20 May 03 by J. Fox
+# last modified 11 June 03 by J. Fox
 
     # Means menu
 
@@ -10,17 +10,17 @@ independentSamplesTTest <- function(){
     tkwm.title(top, "Independent Samples t-Test")
     groupFrame <- tkframe(top)
     responseFrame <- tkframe(top)
+    groupBox <- tklistbox(groupFrame, height=min(4, length(.twoLevelFactors)),
+        selectmode="single", background="white", exportselection="FALSE")
     groupScroll <- tkscrollbar(groupFrame, repeatinterval=5, 
         command=function(...) tkyview(groupBox, ...))
-    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
-        command=function(...) tkyview(responseBox, ...))    
-    groupBox <- tklistbox(groupFrame, height=min(4, length(.twoLevelFactors)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(groupScroll, ...))
+    tkconfigure(groupBox, yscrollcommand=function(...) tkset(groupScroll, ...))
     for (group in .twoLevelFactors) tkinsert(groupBox, "end", group)
     responseBox <- tklistbox(responseFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(responseScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
+        command=function(...) tkyview(responseBox, ...))    
+    tkconfigure(responseBox, yscrollcommand=function(...) tkset(responseScroll, ...))
     for (response in .numeric) tkinsert(responseBox, "end", response)
     onOK <- function(){
         group <- as.character(tkget(groupBox, "active"))
@@ -65,27 +65,33 @@ independentSamplesTTest <- function(){
         tklabel(top, text="Response Variable (pick one)"), sticky="w")
     tkgrid(groupBox, groupScroll, sticky="nw")
     tkgrid(responseBox, responseScroll, sticky="nw")
-    tkgrid.configure(groupScroll, sticky="ns")
-    tkgrid.configure(responseScroll, sticky="ns")
-    tkgrid(groupFrame, responseFrame, sticky="n")
+    tkgrid(groupFrame, responseFrame, sticky="nw")
     tkgrid(tklabel(alternativeFrame, text="Alternative Hypothesis"), columnspan=2, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Two-sided"), twosidedButton, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Difference < 0"), lessButton, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Difference > 0"), greaterButton, sticky="w")
-    tkgrid(tklabel(confidenceFrame, text="Confidence Level"))
-    tkgrid(confidenceField)
+    tkgrid(tklabel(confidenceFrame, text="Confidence Level"),sticky="w")
+    tkgrid(confidenceField, sticky="w")
     tkgrid(tklabel(variancesFrame, text="Assume equal variance?"), columnspan=2, sticky="w")
     tkgrid(tklabel(variancesFrame, text="No"), noButton, sticky="w")
     tkgrid(tklabel(variancesFrame, text="Yes"), yesButton, sticky="w")
-    tkgrid(alternativeFrame, confidenceFrame, variancesFrame, sticky="n")
+    tkgrid(alternativeFrame, confidenceFrame, variancesFrame, sticky="nw")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, tklabel(top, text=""), helpButton, sticky="w")
+    tkgrid.configure(groupScroll, sticky="ns")
+    tkgrid.configure(responseScroll, sticky="ns")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:3) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:2) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkselection.set(groupBox, 0)
     tkselection.set(responseBox, 0)
     tkbind(top, "<Return>", onOK)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
     tkfocus(top)
-    tkgrab(top)
+    tkwait.window(top)
     }
 
 pairedTTest <- function(){
@@ -94,15 +100,15 @@ pairedTTest <- function(){
     tkwm.title(top, "Paired t-Test")
     xFrame <- tkframe(top)
     yFrame <- tkframe(top)
-    xScroll <- tkscrollbar(xFrame, repeatinterval=5, command=function(...) tkyview(xBox, ...))
-    yScroll <- tkscrollbar(yFrame, repeatinterval=5, command=function(...) tkyview(yBox, ...))    
     xBox <- tklistbox(xFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(xScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    xScroll <- tkscrollbar(xFrame, repeatinterval=5, command=function(...) tkyview(xBox, ...))
+    tkconfigure(xBox, yscrollcommand=function(...) tkset(xScroll, ...))
     for (x in .numeric) tkinsert(xBox, "end", x)
     yBox <- tklistbox(yFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(yScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    yScroll <- tkscrollbar(yFrame, repeatinterval=5, command=function(...) tkyview(yBox, ...))    
+    tkconfigure(yBox, yscrollcommand=function(...) tkset(yScroll, ...))
     for (y in .numeric) tkinsert(yBox, "end", y)
     onOK <- function(){
         x <- as.character(tkget(xBox, "active"))
@@ -151,24 +157,30 @@ pairedTTest <- function(){
         tklabel(top, text="Second variable (pick one)"), sticky="w")
     tkgrid(xBox, xScroll, sticky="nw")
     tkgrid(yBox, yScroll, sticky="nw")
-    tkgrid.configure(xScroll, sticky="ns")
-    tkgrid.configure(yScroll, sticky="ns")    
     tkgrid(xFrame, yFrame, sticky="nw")    
     tkgrid(tklabel(alternativeFrame, text="Alternative Hypothesis"), columnspan=2, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Two-sided"), twosidedButton, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Difference < 0"), lessButton, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Difference > 0"), greaterButton, sticky="w")
     tkgrid(tklabel(confidenceFrame, text="Confidence Level"))
-    tkgrid(confidenceField)
-    tkgrid(alternativeFrame, confidenceFrame, sticky="n")
+    tkgrid(confidenceField, sticky="w")
+    tkgrid(alternativeFrame, confidenceFrame, sticky="nw")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, helpButton, sticky="w")
+    tkgrid.configure(xScroll, sticky="ns")
+    tkgrid.configure(yScroll, sticky="ns")    
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:3) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkselection.set(xBox, 0)
     tkselection.set(yBox, 0)
     tkbind(top, "<Return>", onOK)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
     tkfocus(top)
-    tkgrab(top)
+    tkwait.window(top)
     }
 
 singleSampleTTest <- function(){
@@ -176,10 +188,10 @@ singleSampleTTest <- function(){
     top <- tktoplevel()
     tkwm.title(top, "Single-Sample t-Test")
     xFrame <- tkframe(top)
-    xScroll <- tkscrollbar(xFrame, repeatinterval=5, command=function(...) tkyview(xBox, ...))
     xBox <- tklistbox(xFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(xScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    xScroll <- tkscrollbar(xFrame, repeatinterval=5, command=function(...) tkyview(xBox, ...))
+    tkconfigure(xBox, yscrollcommand=function(...) tkset(xScroll, ...))
     for (x in .numeric) tkinsert(xBox, "end", x)
     onOK <- function(){
         x <- .numeric[as.numeric(tkcurselection(xBox)) + 1]
@@ -221,7 +233,6 @@ singleSampleTTest <- function(){
     muField <- tkentry(muFrame, width="8", textvariable=muVariable)
     tkgrid(tklabel(top, text="Variable (pick one)"), sticky="w")
     tkgrid(xBox, xScroll, sticky="nw")
-    tkgrid.configure(xScroll, sticky="ns")
     tkgrid(xFrame, sticky="nw")    
     tkgrid(tklabel(alternativeFrame, text="Alternative Hypothesis"), columnspan=2, sticky="w")
     tkgrid(tklabel(alternativeFrame, text="Population mean = mu0"), twosidedButton, sticky="w")
@@ -230,16 +241,23 @@ singleSampleTTest <- function(){
     tkgrid(tklabel(muFrame, text="Null hypothesis: mu = "), muField, sticky="w")
     tkgrid(muFrame, sticky="w")
     tkgrid(tklabel(confidenceFrame, text="Confidence Level: "), confidenceField, sticky="w")
-    tkgrid.configure(confidenceField, sticky="e")
     tkgrid(confidenceFrame, sticky="w")
-    tkgrid(alternativeFrame, rightFrame)
+    tkgrid(alternativeFrame, rightFrame, sticky="nw")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, helpButton, sticky="w")
+    tkgrid.configure(xScroll, sticky="ns")
+    tkgrid.configure(confidenceField, sticky="e")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:3) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkselection.set(xBox, 0)
     tkbind(top, "<Return>", onOK)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
     tkfocus(top)
-    tkgrab(top)
+    tkwait.window(top)
     }
 
 oneWayAnova <- function(){
@@ -248,17 +266,17 @@ oneWayAnova <- function(){
     tkwm.title(top, "One-Way Analysis of Variance")
     groupFrame <- tkframe(top)
     responseFrame <- tkframe(top)
+    groupBox <- tklistbox(groupFrame, height=min(4, length(.factors)),
+        selectmode="single", background="white", exportselection="FALSE")
     groupScroll <- tkscrollbar(groupFrame, repeatinterval=5, 
         command=function(...) tkyview(groupBox, ...))
-    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
-        command=function(...) tkyview(responseBox, ...))    
-    groupBox <- tklistbox(groupFrame, height=min(4, length(.factors)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(groupScroll, ...))
+    tkconfigure(groupBox, yscrollcommand=function(...) tkset(groupScroll, ...))
     for (group in .factors) tkinsert(groupBox, "end", group)
     responseBox <- tklistbox(responseFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(responseScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
+        command=function(...) tkyview(responseBox, ...))    
+    tkconfigure(responseBox, yscrollcommand=function(...) tkset(responseScroll, ...))
     for (response in .numeric) tkinsert(responseBox, "end", response)
     onOK <- function(){
         group <- as.character(tkget(groupBox, "active"))
@@ -266,9 +284,9 @@ oneWayAnova <- function(){
         tkgrab.release(top)
         tkdestroy(top)
         doItAndPrint(paste("anova(lm(", response, " ~ ", group, "))", sep=""))
-        doItAndPrint(paste("tapply(", response, ", ", group, ", mean) # means", sep=""))
-        doItAndPrint(paste("tapply(", response, ", ", group, ", sd) # std. deviations", sep=""))
-        doItAndPrint(paste("tapply(", response, ", ", group, ", length) # counts", sep=""))
+        doItAndPrint(paste("tapply(", response, ", ", group, ", mean, na.rm=TRUE) # means", sep=""))
+        doItAndPrint(paste("tapply(", response, ", ", group, ", sd, na.rm=TRUE) # std. deviations", sep=""))
+        doItAndPrint(paste("tapply(", response, ", ", group, ", function(x) sum(!is.na(x))) # counts", sep=""))
         tkfocus(.commander)
         }
     buttonsFrame <- tkframe(top)
@@ -289,16 +307,22 @@ oneWayAnova <- function(){
     tkgrid(groupBox, groupScroll, sticky="nw")
     tkgrid(responseBox, responseScroll, sticky="nw")
     tkgrid(groupFrame, responseFrame, sticky="nw")
-    tkgrid.configure(responseScroll, sticky="ns")
-    tkgrid.configure(groupScroll, sticky="ns")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, helpButton, sticky="w")
+    tkgrid.configure(responseScroll, sticky="ns")
+    tkgrid.configure(groupScroll, sticky="ns")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:2) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkselection.set(groupBox, 0)
     tkselection.set(responseBox, 0)
     tkbind(top, "<Return>", onOK)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
     tkfocus(top)
-    tkgrab(top)
+    tkwait.window(top)
     }
     
 multiWayAnova <- function(){
@@ -307,17 +331,17 @@ multiWayAnova <- function(){
     tkwm.title(top, "Multi-Way Analysis of Variance")
     groupFrame <- tkframe(top)
     responseFrame <- tkframe(top)
+    groupBox <- tklistbox(groupFrame, height=min(4, length(.factors)),
+        selectmode="multiple", background="white", exportselection="FALSE")
     groupScroll <- tkscrollbar(groupFrame, repeatinterval=5, 
         command=function(...) tkyview(groupBox, ...))
-    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
-        command=function(...) tkyview(responseBox, ...))    
-    groupBox <- tklistbox(groupFrame, height=min(4, length(.factors)),
-        selectmode="multiple", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(groupScroll, ...))
+    tkconfigure(groupBox, yscrollcommand=function(...) tkset(groupScroll, ...))
     for (group in .factors) tkinsert(groupBox, "end", group)
     responseBox <- tklistbox(responseFrame, height=min(4, length(.numeric)),
-        selectmode="single", background="white", exportselection="FALSE",
-        yscrollcommand=function(...) tkset(responseScroll, ...))
+        selectmode="single", background="white", exportselection="FALSE")
+    responseScroll <- tkscrollbar(responseFrame, repeatinterval=5, 
+        command=function(...) tkyview(responseBox, ...))    
+    tkconfigure(responseBox, yscrollcommand=function(...) tkset(responseScroll, ...))
     for (response in .numeric) tkinsert(responseBox, "end", response)
     onOK <- function(){
         groups <- .factors[as.numeric(tkcurselection(groupBox)) + 1]
@@ -336,11 +360,11 @@ multiWayAnova <- function(){
         doItAndPrint(paste("Anova(lm(", response, " ~ ", paste(groups, collapse="*"),
              "))", sep=""))
         doItAndPrint(paste("tapply(", response, ", list(", groups.list,
-             "), mean) # means", sep=""))
+             "), mean, na.rm=TRUE) # means", sep=""))
         doItAndPrint(paste("tapply(", response, ", list(", groups.list,
-             "), sd) # std. deviations", sep=""))
+             "), sd, na.rm=TRUE) # std. deviations", sep=""))
         doItAndPrint(paste("tapply(", response, ", list(", groups.list,
-             "), length) # counts", sep=""))
+             "), function(x) sum(!is.na(x))) # counts", sep=""))
         tkfocus(.commander)
         }
     buttonsFrame <- tkframe(top)
@@ -361,13 +385,19 @@ multiWayAnova <- function(){
     tkgrid(groupBox, groupScroll, sticky="nw")
     tkgrid(responseBox, responseScroll, sticky="nw")
     tkgrid(groupFrame, responseFrame, sticky="nw")
-    tkgrid.configure(responseScroll, sticky="ns")
-    tkgrid.configure(groupScroll, sticky="ns")
     tkgrid(OKbutton, cancelButton, sticky="w")
     tkgrid(buttonsFrame, helpButton, sticky="w")
+    tkgrid.configure(responseScroll, sticky="ns")
+    tkgrid.configure(groupScroll, sticky="ns")
     tkgrid.configure(helpButton, sticky="e")
+    for (row in 0:2) tkgrid.rowconfigure(top, row, weight=0)
+    for (col in 0:1) tkgrid.columnconfigure(top, col, weight=0)
+    .Tcl("update idletasks")
+    tkwm.resizable(top, 0, 0)
     tkselection.set(responseBox, 0)
     tkbind(top, "<Return>", onOK)
+    tkwm.deiconify(top)
+    tkgrab.set(top)
     tkfocus(top)
-    tkgrab(top)
+    tkwait.window(top)
     }
